@@ -37,8 +37,9 @@
  * WWW URL: http://cs.nyu.edu/exact/
  * Email: exact@cs.nyu.edu
  *
- * $URL$
- * $Id$
+ * $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/CGAL_Core/include/CGAL/CORE/BigFloat_impl.h $
+ * $Id: BigFloat_impl.h 78e7060 2018-02-19T14:27:06+01:00 Laurent Rineau
+ * SPDX-License-Identifier: LGPL-3.0+
  ***************************************************************************/
 
 #ifdef CGAL_HEADER_ONLY
@@ -47,9 +48,13 @@
 #define CGAL_INLINE_FUNCTION
 #endif
 
+#include <CGAL/disable_warnings.h>
+
 #include <ctype.h>
 #include <CGAL/CORE/BigFloat.h>
 #include <CGAL/CORE/Expr.h>
+#include <CGAL/tss.h>
+#include <sstream> 
 
 namespace CORE { 
 
@@ -84,13 +89,13 @@ BigInt FiveTo(unsigned long exp) {
 // ZERO
 CGAL_INLINE_FUNCTION
 const BigFloat& BigFloat::getZero() {
-  static BigFloat Zero(0);
+  CGAL_STATIC_THREAD_LOCAL_VARIABLE(BigFloat, Zero,0);
   return Zero;
 }
 // ONE
 CGAL_INLINE_FUNCTION
 const BigFloat& BigFloat::getOne() {
-  static BigFloat One(1);
+  CGAL_STATIC_THREAD_LOCAL_VARIABLE(BigFloat, One,1);
   return One;
 }
 
@@ -136,8 +141,8 @@ BigFloatRep::BigFloatRep(double d) : m(0), err(0), exp(0) {
       exp--;
       stop++;
     }
-#ifdef CORE_DEBUG
-    assert (s >= 0);
+#ifdef CGAL_CORE_DEBUG
+    CGAL_assertion (s >= 0);
 #endif
 
     if (s)
@@ -276,8 +281,8 @@ void BigFloatRep::normal() {
 	                     // bits of error
     long f = chunkFloor(--le); // f is roughly equal to floor(le/CHUNK_BIT)
     long bits_f = bits(f);   // f chunks will have bits_f many bits
-#ifdef CORE_DEBUG
-    assert (bits_f >= 0);
+#ifdef CGAL_CORE_DEBUG
+    CGAL_assertion (bits_f >= 0);
 #endif
 
     m   >>= bits_f;  // reduce mantissa by bits_f many bits
@@ -304,8 +309,8 @@ void BigFloatRep::bigNormal(BigInt& bigErr) {
   } else {
     long f = chunkFloor(--le);
     long bits_f = bits(f);
-#ifdef CORE_DEBUG
-    assert(bits_f >= 0);
+#ifdef CGAL_CORE_DEBUG
+    CGAL_assertion(bits_f >= 0);
 #endif
 
     m      >>= bits_f;
@@ -683,8 +688,8 @@ void BigFloatRep::sqrt(const BigFloatRep& x, const extLong& a, const BigFloat& A
         } else {                  //  p > 0
           m = chunkShift(z.m, chunkCeil(p));
           long r = CHUNK_BIT - 1 - (p + CHUNK_BIT - 1) % CHUNK_BIT;
-#ifdef CORE_DEBUG
-          assert(r >= 0);
+#ifdef CGAL_CORE_DEBUG
+          CGAL_assertion(r >= 0);
 #endif
 
           err = 1 >> r;
@@ -726,8 +731,8 @@ void BigFloatRep::sqrt(const BigFloatRep& x, const extLong& a, const BigFloat& A
         } else {         //  q > 0
           m = chunkShift(z.m, chunkCeil(q));
           long r = CHUNK_BIT - 1 - (q + CHUNK_BIT - 1) % CHUNK_BIT;
-#ifdef CORE_DEBUG
-          assert(r >= 0);
+#ifdef CGAL_CORE_DEBUG
+          CGAL_assertion(r >= 0);
 #endif
 
           err = 1 >> r;
@@ -917,16 +922,9 @@ BigFloatRep::toDecimal(unsigned int width, bool Scientific) const {
       } else { // L10 < 0
         decRep += '-';
       }
-      char eBuf[48]; // enought to hold long number L10
-      int ne = 0;
-      if ((ne = sprintf(eBuf, "%ld", labs(L10))) >= 0) {
-        eBuf[ne] = '\0';
-      } else {
-        //perror("BigFloat.cpp: Problem in outputing the exponent!");
-        core_error("BigFloat error: Problem in outputing the exponent",
-			__FILE__, __LINE__, true);
-      }
-      decRep += eBuf;
+      std::ostringstream oss;
+      oss << labs(L10);
+      decRep += oss.str();
       decOut.isScientific = true;
     }
   } else {
@@ -940,7 +938,7 @@ BigFloatRep::toDecimal(unsigned int width, bool Scientific) const {
           return toDecimal(width, true);
         }
       }
-      decOut.noSignificant = decRep.length();
+      decOut.noSignificant = static_cast<int>(decRep.length());
       if (L10 + 1 < (long)width ) {
         decRep.insert(L10 + 1, ".");
       } else { // L10 + 1 == width
@@ -955,13 +953,13 @@ BigFloatRep::toDecimal(unsigned int width, bool Scientific) const {
         decRep = round(decRep, L10, width );
         // cannot overflow since there are L10 leading zeroes.
       }
-      decOut.noSignificant = decRep.length() - (-L10);
+      decOut.noSignificant = static_cast<int>(decRep.length() - (-L10));
       decRep.insert(1, ".");
     }
     decOut.isScientific = false;
   }
-#ifdef CORE_DEBUG
-  assert(decOut.noSignificant >= 0);
+#ifdef CGAL_CORE_DEBUG
+  CGAL_assertion(decOut.noSignificant >= 0);
 #endif
 
   decOut.rep = decRep;
@@ -1009,7 +1007,7 @@ std::string BigFloatRep::round(std::string inRep, long& L10, unsigned int width)
 // See the file Real.cc for the differences
 
 CGAL_INLINE_FUNCTION
-void BigFloatRep :: fromString(const char *str, const extLong & prec ) {
+void BigFloatRep :: fromString(const char *str, extLong prec ) {
   // NOTE: prec defaults to get_static_defBigFloatInputDigits() (see BigFloat.h)
   // check that prec is not INFTY
   if (prec.isInfty())
@@ -1024,8 +1022,8 @@ void BigFloatRep :: fromString(const char *str, const extLong & prec ) {
   // i.e., input is A/10^{e10}.
   else {
     e = str + strlen(str);
-#ifdef CORE_DEBUG
-    assert(*e == '\0');
+#ifdef CGAL_CORE_DEBUG
+    CGAL_assertion(*e == '\0');
 #endif
 
   }
@@ -1083,7 +1081,7 @@ std::istream& BigFloatRep :: operator >>(std::istream& i) {
   // Change to:
   //  int status;
   do {
-    c = i.get();
+    i.get(c);
   } while (isspace(c)); /* loop if met end-of-file, or
                                char read in is white-space. */
   // Chen Li, "if (c == EOF)" is unsafe since c is of char type and
@@ -1115,8 +1113,8 @@ std::istream& BigFloatRep :: operator >>(std::istream& i) {
       p = str + size;
       size *= 2;
     }
-#ifdef CORE_DEBUG
-    assert((p-str) < size);
+#ifdef CGAL_CORE_DEBUG
+    CGAL_assertion((p-str) < size);
 #endif
 
     *p++ = c;
@@ -1133,7 +1131,7 @@ std::istream& BigFloatRep :: operator >>(std::istream& i) {
 
   // chenli: make sure that the p is still in the range
   if (p - str >= size) {
-    int len = p - str;
+    std::size_t len = p - str;
     char *t = str;
     str = new char[len + 1];
     memcpy(str, t, len);
@@ -1141,8 +1139,8 @@ std::istream& BigFloatRep :: operator >>(std::istream& i) {
     p = str + len;
   }
 
-#ifdef CORE_DEBUG
-  assert(p - str < size);
+#ifdef CGAL_CORE_DEBUG
+  CGAL_assertion(p - str < size);
 #endif
 
   *p = '\0';
@@ -1228,8 +1226,8 @@ BigInt BigFloatRep::toBigInt() const {
   long le = clLg(err);
   if (le == -1)
     le = 0;
-#ifdef CORE_DEBUG
-  assert (le >= 0);
+#ifdef CGAL_CORE_DEBUG
+  CGAL_assertion (le >= 0);
 #endif
 
   BigInt M = m >> static_cast<unsigned long>(le); // discard the contaminated bits.
@@ -1248,8 +1246,8 @@ long BigFloatRep :: toLong() const {
   // convert a BigFloat to a long integer, rounded toward -\infty.
   long e2 = bits(exp);
   long le = clLg(err);
-#ifdef CORE_DEBUG
-  assert (le >= 0);
+#ifdef CGAL_CORE_DEBUG
+  CGAL_assertion (le >= 0);
 #endif
 
   BigInt M = m >> static_cast<unsigned long>(le); // discard the contaminated bits.
@@ -1325,3 +1323,5 @@ BigFloat root(const BigFloat& x, unsigned long k,
   CORE_MEMORY_IMPL(BigFloatRep)
 
 } //namespace CORE
+
+#include <CGAL/enable_warnings.h>
