@@ -16,8 +16,9 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Kernel_23/include/CGAL/aff_transformation_tags.h $
+// $Id: aff_transformation_tags.h 0698f79 2017-10-20T23:34:14+02:00 Sébastien Loriot
+// SPDX-License-Identifier: LGPL-3.0+
 // 
 //
 // Author(s)     : Andreas Fabri
@@ -26,7 +27,7 @@
 #ifndef CGAL_AFF_TRANSFORMATION_TAGS_H
 #define CGAL_AFF_TRANSFORMATION_TAGS_H
 
-#include <CGAL/basic.h>
+#include <CGAL/config.h>
 
 namespace CGAL {
 
@@ -36,12 +37,19 @@ class Scaling {};
 class Reflection {};
 class Identity_transformation {};
 
-CGAL_EXPORT extern const Translation             TRANSLATION;
-CGAL_EXPORT extern const Rotation                ROTATION;
-CGAL_EXPORT extern const Scaling                 SCALING;
-CGAL_EXPORT extern const Reflection              REFLECTION;
-CGAL_EXPORT extern const Identity_transformation IDENTITY;
+#ifndef CGAL_HEADER_ONLY
+
+CGAL_EXPORT extern const Translation              TRANSLATION;
+CGAL_EXPORT extern const Rotation                 ROTATION;
+CGAL_EXPORT extern const Scaling                  SCALING;
+CGAL_EXPORT extern const Reflection               REFLECTION;
+CGAL_EXPORT extern const Identity_transformation  IDENTITY;
+
+#endif
 
 } //namespace CGAL
+#ifdef CGAL_HEADER_ONLY
+#include <CGAL/aff_transformation_tags_impl.h>
+#endif // CGAL_HEADER_ONLY
 
 #endif // CGAL_AFF_TRANSFORMATION_TAGS_H
